@@ -145,7 +145,7 @@ class Transformer(nn.Module):
         image_fmap_size = None,
         sparse_attn = False,
         stable = False,
-        shift_tokens = False,
+        shift_tokens = True,
         rotary_emb = True
     ):
         super().__init__()
